# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from stellarstation.api.v1 import stellarstation_pb2 as stellarstation_dot_api_dot_v1_dot_stellarstation__pb2


class StellarStationServiceStub(object):
  """The public API service of Stellarstation, a system supporting communication between satellites
  and ground stations. This API is for use by an operator of a satellite - it is invalid to specify
  satellites that the operator does not own or plans they have not reserved.
  Only using IDs shown on the StellarStation Console or returned in API responses will ensure all
  inputs are valid.

  A pass is a time range where an ground station and satellite can communicate with each other, i.e.,
  the period between Acquisition of Signal (AOS) and Loss of Signal (LOS) of the ground station and
  satellite pair.

  A plan is a scheduled pass that will be executed to send and receive data between the ground
  station and satellite during the time range.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.ListGroundStationPlans = channel.unary_unary(
        '/stellarstation.api.v1.StellarStationService/ListGroundStationPlans',
        request_serializer=stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.ListGroundStationPlansRequest.SerializeToString,
        response_deserializer=stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.ListGroundStationPlansResponse.FromString,
        )
    self.OpenSatelliteStream = channel.stream_stream(
        '/stellarstation.api.v1.StellarStationService/OpenSatelliteStream',
        request_serializer=stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.SatelliteStreamRequest.SerializeToString,
        response_deserializer=stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.SatelliteStreamResponse.FromString,
        )


class StellarStationServiceServicer(object):
  """The public API service of Stellarstation, a system supporting communication between satellites
  and ground stations. This API is for use by an operator of a satellite - it is invalid to specify
  satellites that the operator does not own or plans they have not reserved.
  Only using IDs shown on the StellarStation Console or returned in API responses will ensure all
  inputs are valid.

  A pass is a time range where an ground station and satellite can communicate with each other, i.e.,
  the period between Acquisition of Signal (AOS) and Loss of Signal (LOS) of the ground station and
  satellite pair.

  A plan is a scheduled pass that will be executed to send and receive data between the ground
  station and satellite during the time range.
  """

  def ListGroundStationPlans(self, request, context):
    """Lists the plans for a particular ground station.

    The request will be closed with an `INVALID_ARGUMENT` status if `ground_station_id`,
    `aos_after`, or `aos_before` are missing, or the duration between the two times is longer than
    31 days.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def OpenSatelliteStream(self, request_iterator, context):
    """Open a stream to a satellite. The returned stream is bi-directional - it can be used by the
    client to send commands to the satellite and data received from the satellite will be returned
    as it is made available. All telemetry received from the satellite on reserved passes from this
    point on will be returned as soon as this method is called. If
    `SatelliteStreamRequest.stream_id` is specified, any messages that have been buffered for the
    stream will be returned as well.

    The stream can be left open for any amount of time and telemetry will be received as available
    and returned. When the client is done with the stream, it should close it successfully. If the
    stream is cancelled with an unexpected error at any point, telemetry received before the next
    call to `OpenSatelliteStream` to resume the stream will be buffered up to 1 minute, and if no
    call to `OpenSatelliteStream` is made with `stream_id` specified to resume the stream, it will
    expire in 10 minutes and a call to `OpenSatelliteStream` with that `stream_id` will be closed
    with a `ABORTED` error.

    If the satellite is not found or the client is not authorized for it, the stream will be closed
    with a `NOT_FOUND` error.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_StellarStationServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'ListGroundStationPlans': grpc.unary_unary_rpc_method_handler(
          servicer.ListGroundStationPlans,
          request_deserializer=stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.ListGroundStationPlansRequest.FromString,
          response_serializer=stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.ListGroundStationPlansResponse.SerializeToString,
      ),
      'OpenSatelliteStream': grpc.stream_stream_rpc_method_handler(
          servicer.OpenSatelliteStream,
          request_deserializer=stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.SatelliteStreamRequest.FromString,
          response_serializer=stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.SatelliteStreamResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'stellarstation.api.v1.StellarStationService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: stellarstation/api/v1/stellarstation.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='stellarstation/api/v1/stellarstation.proto',
  package='stellarstation.api.v1',
  syntax='proto3',
  serialized_pb=_b('\n*stellarstation/api/v1/stellarstation.proto\x12\x15stellarstation.api.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\xe6\x01\n\x16SatelliteStreamRequest\x12\x14\n\x0csatellite_id\x18\x01 \x01(\t\x12\x11\n\tstream_id\x18\x02 \x01(\t\x12^\n\x1fsend_satellite_commands_request\x18\x03 \x01(\x0b\x32\x33.stellarstation.api.v1.SendSatelliteCommandsRequestH\x00\x12\x38\n\x10\x61\x63\x63\x65pted_framing\x18\x04 \x03(\x0e\x32\x1e.stellarstation.api.v1.FramingB\t\n\x07Request\"/\n\x1cSendSatelliteCommandsRequest\x12\x0f\n\x07\x63ommand\x18\x02 \x03(\x0c\"\x8f\x01\n\x17SatelliteStreamResponse\x12\x11\n\tstream_id\x18\x01 \x01(\t\x12U\n\x1areceive_telemetry_response\x18\x02 \x01(\x0b\x32/.stellarstation.api.v1.ReceiveTelemetryResponseH\x00\x42\n\n\x08Response\"O\n\x18ReceiveTelemetryResponse\x12\x33\n\ttelemetry\x18\x01 \x01(\x0b\x32 .stellarstation.api.v1.Telemetry\"\xfa\x01\n\tTelemetry\x12/\n\x07\x66raming\x18\x01 \x01(\x0e\x32\x1e.stellarstation.api.v1.Framing\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x12\x1d\n\x15\x64ownlink_frequency_hz\x18\x03 \x01(\x04\x12<\n\x18time_first_byte_received\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12;\n\x17time_last_byte_received\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x14\n\x0c\x66rame_header\x18\x06 \x01(\x0c\"\x99\x01\n\x1dListGroundStationPlansRequest\x12\x19\n\x11ground_station_id\x18\x01 \x01(\t\x12-\n\taos_after\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\naos_before\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"K\n\x1eListGroundStationPlansResponse\x12)\n\x04plan\x18\x01 \x03(\x0b\x32\x1b.stellarstation.api.v1.Plan\"\xc2\x03\n\x04Plan\x12\x0f\n\x07plan_id\x18\x01 \x01(\t\x12\x32\n\x06status\x18\x02 \x01(\x0e\x32\".stellarstation.api.v1.Plan.Status\x12\'\n\x03tle\x18\x03 \x01(\x0b\x32\x1a.stellarstation.api.v1.Tle\x12,\n\x08\x61os_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08los_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12$\n\x1c\x64ownlink_center_frequency_hz\x18\x06 \x01(\x04\x12\"\n\x1auplink_center_frequency_hz\x18\x07 \x01(\x04\x12\x1d\n\x15max_elevation_degrees\x18\x08 \x01(\x01\x12\x36\n\x12max_elevation_time\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"O\n\x06Status\x12\x0c\n\x08RESERVED\x10\x00\x12\r\n\tEXECUTING\x10\x01\x12\r\n\tSUCCEEDED\x10\x02\x12\n\n\x06\x46\x41ILED\x10\x03\x12\r\n\tCANCELLED\x10\x04\"%\n\x03Tle\x12\x0e\n\x06line_1\x18\x01 \x01(\t\x12\x0e\n\x06line_2\x18\x02 \x01(\t*9\n\x07\x46raming\x12\r\n\tBITSTREAM\x10\x00\x12\x08\n\x04\x41X25\x10\x01\x12\x06\n\x02IQ\x10\x02\x12\r\n\tIMAGE_PNG\x10\x03\x32\x99\x02\n\x15StellarStationService\x12\x85\x01\n\x16ListGroundStationPlans\x12\x34.stellarstation.api.v1.ListGroundStationPlansRequest\x1a\x35.stellarstation.api.v1.ListGroundStationPlansResponse\x12x\n\x13OpenSatelliteStream\x12-.stellarstation.api.v1.SatelliteStreamRequest\x1a..stellarstation.api.v1.SatelliteStreamResponse(\x01\x30\x01\x42\x42\n\x19\x63om.stellarstation.api.v1B\x13StellarstationProtoP\x01Z\x0estellarstationb\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])

_FRAMING = _descriptor.EnumDescriptor(
  name='Framing',
  full_name='stellarstation.api.v1.Framing',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BITSTREAM', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AX25', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IQ', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IMAGE_PNG', index=3, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1589,
  serialized_end=1646,
)
_sym_db.RegisterEnumDescriptor(_FRAMING)

Framing = enum_type_wrapper.EnumTypeWrapper(_FRAMING)
BITSTREAM = 0
AX25 = 1
IQ = 2
IMAGE_PNG = 3


_PLAN_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='stellarstation.api.v1.Plan.Status',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RESERVED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EXECUTING', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SUCCEEDED', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILED', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANCELLED', index=4, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1469,
  serialized_end=1548,
)
_sym_db.RegisterEnumDescriptor(_PLAN_STATUS)


_SATELLITESTREAMREQUEST = _descriptor.Descriptor(
  name='SatelliteStreamRequest',
  full_name='stellarstation.api.v1.SatelliteStreamRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='satellite_id', full_name='stellarstation.api.v1.SatelliteStreamRequest.satellite_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stream_id', full_name='stellarstation.api.v1.SatelliteStreamRequest.stream_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='send_satellite_commands_request', full_name='stellarstation.api.v1.SatelliteStreamRequest.send_satellite_commands_request', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='accepted_framing', full_name='stellarstation.api.v1.SatelliteStreamRequest.accepted_framing', index=3,
      number=4, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='Request', full_name='stellarstation.api.v1.SatelliteStreamRequest.Request',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=103,
  serialized_end=333,
)


_SENDSATELLITECOMMANDSREQUEST = _descriptor.Descriptor(
  name='SendSatelliteCommandsRequest',
  full_name='stellarstation.api.v1.SendSatelliteCommandsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='command', full_name='stellarstation.api.v1.SendSatelliteCommandsRequest.command', index=0,
      number=2, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=335,
  serialized_end=382,
)


_SATELLITESTREAMRESPONSE = _descriptor.Descriptor(
  name='SatelliteStreamResponse',
  full_name='stellarstation.api.v1.SatelliteStreamResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stream_id', full_name='stellarstation.api.v1.SatelliteStreamResponse.stream_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='receive_telemetry_response', full_name='stellarstation.api.v1.SatelliteStreamResponse.receive_telemetry_response', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='Response', full_name='stellarstation.api.v1.SatelliteStreamResponse.Response',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=385,
  serialized_end=528,
)


_RECEIVETELEMETRYRESPONSE = _descriptor.Descriptor(
  name='ReceiveTelemetryResponse',
  full_name='stellarstation.api.v1.ReceiveTelemetryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='telemetry', full_name='stellarstation.api.v1.ReceiveTelemetryResponse.telemetry', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=530,
  serialized_end=609,
)


_TELEMETRY = _descriptor.Descriptor(
  name='Telemetry',
  full_name='stellarstation.api.v1.Telemetry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='framing', full_name='stellarstation.api.v1.Telemetry.framing', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='stellarstation.api.v1.Telemetry.data', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='downlink_frequency_hz', full_name='stellarstation.api.v1.Telemetry.downlink_frequency_hz', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time_first_byte_received', full_name='stellarstation.api.v1.Telemetry.time_first_byte_received', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time_last_byte_received', full_name='stellarstation.api.v1.Telemetry.time_last_byte_received', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='frame_header', full_name='stellarstation.api.v1.Telemetry.frame_header', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=612,
  serialized_end=862,
)


_LISTGROUNDSTATIONPLANSREQUEST = _descriptor.Descriptor(
  name='ListGroundStationPlansRequest',
  full_name='stellarstation.api.v1.ListGroundStationPlansRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ground_station_id', full_name='stellarstation.api.v1.ListGroundStationPlansRequest.ground_station_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='aos_after', full_name='stellarstation.api.v1.ListGroundStationPlansRequest.aos_after', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='aos_before', full_name='stellarstation.api.v1.ListGroundStationPlansRequest.aos_before', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=865,
  serialized_end=1018,
)


_LISTGROUNDSTATIONPLANSRESPONSE = _descriptor.Descriptor(
  name='ListGroundStationPlansResponse',
  full_name='stellarstation.api.v1.ListGroundStationPlansResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='plan', full_name='stellarstation.api.v1.ListGroundStationPlansResponse.plan', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1020,
  serialized_end=1095,
)


_PLAN = _descriptor.Descriptor(
  name='Plan',
  full_name='stellarstation.api.v1.Plan',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='plan_id', full_name='stellarstation.api.v1.Plan.plan_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='stellarstation.api.v1.Plan.status', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tle', full_name='stellarstation.api.v1.Plan.tle', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='aos_time', full_name='stellarstation.api.v1.Plan.aos_time', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='los_time', full_name='stellarstation.api.v1.Plan.los_time', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='downlink_center_frequency_hz', full_name='stellarstation.api.v1.Plan.downlink_center_frequency_hz', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uplink_center_frequency_hz', full_name='stellarstation.api.v1.Plan.uplink_center_frequency_hz', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_elevation_degrees', full_name='stellarstation.api.v1.Plan.max_elevation_degrees', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_elevation_time', full_name='stellarstation.api.v1.Plan.max_elevation_time', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PLAN_STATUS,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1098,
  serialized_end=1548,
)


_TLE = _descriptor.Descriptor(
  name='Tle',
  full_name='stellarstation.api.v1.Tle',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='line_1', full_name='stellarstation.api.v1.Tle.line_1', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='line_2', full_name='stellarstation.api.v1.Tle.line_2', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1550,
  serialized_end=1587,
)

_SATELLITESTREAMREQUEST.fields_by_name['send_satellite_commands_request'].message_type = _SENDSATELLITECOMMANDSREQUEST
_SATELLITESTREAMREQUEST.fields_by_name['accepted_framing'].enum_type = _FRAMING
_SATELLITESTREAMREQUEST.oneofs_by_name['Request'].fields.append(
  _SATELLITESTREAMREQUEST.fields_by_name['send_satellite_commands_request'])
_SATELLITESTREAMREQUEST.fields_by_name['send_satellite_commands_request'].containing_oneof = _SATELLITESTREAMREQUEST.oneofs_by_name['Request']
_SATELLITESTREAMRESPONSE.fields_by_name['receive_telemetry_response'].message_type = _RECEIVETELEMETRYRESPONSE
_SATELLITESTREAMRESPONSE.oneofs_by_name['Response'].fields.append(
  _SATELLITESTREAMRESPONSE.fields_by_name['receive_telemetry_response'])
_SATELLITESTREAMRESPONSE.fields_by_name['receive_telemetry_response'].containing_oneof = _SATELLITESTREAMRESPONSE.oneofs_by_name['Response']
_RECEIVETELEMETRYRESPONSE.fields_by_name['telemetry'].message_type = _TELEMETRY
_TELEMETRY.fields_by_name['framing'].enum_type = _FRAMING
_TELEMETRY.fields_by_name['time_first_byte_received'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TELEMETRY.fields_by_name['time_last_byte_received'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTGROUNDSTATIONPLANSREQUEST.fields_by_name['aos_after'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTGROUNDSTATIONPLANSREQUEST.fields_by_name['aos_before'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTGROUNDSTATIONPLANSRESPONSE.fields_by_name['plan'].message_type = _PLAN
_PLAN.fields_by_name['status'].enum_type = _PLAN_STATUS
_PLAN.fields_by_name['tle'].message_type = _TLE
_PLAN.fields_by_name['aos_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PLAN.fields_by_name['los_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PLAN.fields_by_name['max_elevation_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PLAN_STATUS.containing_type = _PLAN
DESCRIPTOR.message_types_by_name['SatelliteStreamRequest'] = _SATELLITESTREAMREQUEST
DESCRIPTOR.message_types_by_name['SendSatelliteCommandsRequest'] = _SENDSATELLITECOMMANDSREQUEST
DESCRIPTOR.message_types_by_name['SatelliteStreamResponse'] = _SATELLITESTREAMRESPONSE
DESCRIPTOR.message_types_by_name['ReceiveTelemetryResponse'] = _RECEIVETELEMETRYRESPONSE
DESCRIPTOR.message_types_by_name['Telemetry'] = _TELEMETRY
DESCRIPTOR.message_types_by_name['ListGroundStationPlansRequest'] = _LISTGROUNDSTATIONPLANSREQUEST
DESCRIPTOR.message_types_by_name['ListGroundStationPlansResponse'] = _LISTGROUNDSTATIONPLANSRESPONSE
DESCRIPTOR.message_types_by_name['Plan'] = _PLAN
DESCRIPTOR.message_types_by_name['Tle'] = _TLE
DESCRIPTOR.enum_types_by_name['Framing'] = _FRAMING
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SatelliteStreamRequest = _reflection.GeneratedProtocolMessageType('SatelliteStreamRequest', (_message.Message,), dict(
  DESCRIPTOR = _SATELLITESTREAMREQUEST,
  __module__ = 'stellarstation.api.v1.stellarstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.SatelliteStreamRequest)
  ))
_sym_db.RegisterMessage(SatelliteStreamRequest)

SendSatelliteCommandsRequest = _reflection.GeneratedProtocolMessageType('SendSatelliteCommandsRequest', (_message.Message,), dict(
  DESCRIPTOR = _SENDSATELLITECOMMANDSREQUEST,
  __module__ = 'stellarstation.api.v1.stellarstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.SendSatelliteCommandsRequest)
  ))
_sym_db.RegisterMessage(SendSatelliteCommandsRequest)

SatelliteStreamResponse = _reflection.GeneratedProtocolMessageType('SatelliteStreamResponse', (_message.Message,), dict(
  DESCRIPTOR = _SATELLITESTREAMRESPONSE,
  __module__ = 'stellarstation.api.v1.stellarstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.SatelliteStreamResponse)
  ))
_sym_db.RegisterMessage(SatelliteStreamResponse)

ReceiveTelemetryResponse = _reflection.GeneratedProtocolMessageType('ReceiveTelemetryResponse', (_message.Message,), dict(
  DESCRIPTOR = _RECEIVETELEMETRYRESPONSE,
  __module__ = 'stellarstation.api.v1.stellarstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.ReceiveTelemetryResponse)
  ))
_sym_db.RegisterMessage(ReceiveTelemetryResponse)

Telemetry = _reflection.GeneratedProtocolMessageType('Telemetry', (_message.Message,), dict(
  DESCRIPTOR = _TELEMETRY,
  __module__ = 'stellarstation.api.v1.stellarstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.Telemetry)
  ))
_sym_db.RegisterMessage(Telemetry)

ListGroundStationPlansRequest = _reflection.GeneratedProtocolMessageType('ListGroundStationPlansRequest', (_message.Message,), dict(
  DESCRIPTOR = _LISTGROUNDSTATIONPLANSREQUEST,
  __module__ = 'stellarstation.api.v1.stellarstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.ListGroundStationPlansRequest)
  ))
_sym_db.RegisterMessage(ListGroundStationPlansRequest)

ListGroundStationPlansResponse = _reflection.GeneratedProtocolMessageType('ListGroundStationPlansResponse', (_message.Message,), dict(
  DESCRIPTOR = _LISTGROUNDSTATIONPLANSRESPONSE,
  __module__ = 'stellarstation.api.v1.stellarstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.ListGroundStationPlansResponse)
  ))
_sym_db.RegisterMessage(ListGroundStationPlansResponse)

Plan = _reflection.GeneratedProtocolMessageType('Plan', (_message.Message,), dict(
  DESCRIPTOR = _PLAN,
  __module__ = 'stellarstation.api.v1.stellarstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.Plan)
  ))
_sym_db.RegisterMessage(Plan)

Tle = _reflection.GeneratedProtocolMessageType('Tle', (_message.Message,), dict(
  DESCRIPTOR = _TLE,
  __module__ = 'stellarstation.api.v1.stellarstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.Tle)
  ))
_sym_db.RegisterMessage(Tle)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\031com.stellarstation.api.v1B\023StellarstationProtoP\001Z\016stellarstation'))

_STELLARSTATIONSERVICE = _descriptor.ServiceDescriptor(
  name='StellarStationService',
  full_name='stellarstation.api.v1.StellarStationService',
  file=DESCRIPTOR,
  index=0,
  options=None,
  serialized_start=1649,
  serialized_end=1930,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListGroundStationPlans',
    full_name='stellarstation.api.v1.StellarStationService.ListGroundStationPlans',
    index=0,
    containing_service=None,
    input_type=_LISTGROUNDSTATIONPLANSREQUEST,
    output_type=_LISTGROUNDSTATIONPLANSRESPONSE,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='OpenSatelliteStream',
    full_name='stellarstation.api.v1.StellarStationService.OpenSatelliteStream',
    index=1,
    containing_service=None,
    input_type=_SATELLITESTREAMREQUEST,
    output_type=_SATELLITESTREAMRESPONSE,
    options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_STELLARSTATIONSERVICE)

DESCRIPTOR.services_by_name['StellarStationService'] = _STELLARSTATIONSERVICE

# @@protoc_insertion_point(module_scope)
